.redux-container-button_color {
    .buttonColor {
        display: inline-block;
        padding-right: 10px;
        padding-bottom: 7px;
        
        strong {
            display: table;
            margin-bottom: 5px;
            margin-left: 3px;
            font-size: 12px;
            font-weight: normal;
            color: #999;            
        }
    }
}

