/*global redux_change, redux*/

(function( $ ) {
    "use strict";

    redux.field_objects = redux.field_objects || {};
    redux.field_objects.multi_bp_select = redux.field_objects.multi_bp_select || {};

    $( document ).ready(
        function() {
            //redux.field_objects.multi_text.init();
        }
    );

    redux.field_objects.multi_bp_select.init = function( selector ) {

        if ( !selector ) {
            selector = $( document ).find( '.redux-container-multi_bp_select:visible' );
        }

        $( selector ).each(
            function() {
                var el = $( this );
                var parent = el;
                if ( !el.hasClass( 'redux-field-container' ) ) {
                    parent = el.parents( '.redux-field-container:first' );
                }
                if ( parent.is( ":hidden" ) ) { // Skip hidden fields
                    return;
                }
                if ( parent.hasClass( 'redux-field-init' ) ) {
                    parent.removeClass( 'redux-field-init' );
                } else {
                    return;
                }
                el.find( '.redux-multi-bp-select-remove' ).live(
                    'click', function() {
                        redux_change( $( this ) );
                        $( this ).prev( 'input[type="text"]' ).val( '' );
                        $( this ).parent().slideUp(
                            'medium', function() {
                                $( this ).remove();
                            }
                        );
                    }
                );

                el.find( '.redux-multi-bp-select-add' ).click(
                    function() {
                        var number  = parseInt( $( this ).attr( 'data-add_number' ), 10);
                        var id      = $( this ).attr( 'data-id' );
                        var last_id = $( '#' + id + ' li:last-child' ).attr( 'data-id' );
                        var name    = $( this ).attr( 'data-name' ) + '['+(parseInt(last_id,10)+1)+']';
                        for ( var i = 0; i < number; i++ ) {
                            //debugger;
                            var new_input = $( '#' + id + ' li:last-child' ).clone();
                            el.find( '#' + id ).append( new_input );
                            el.find( '#' + id + ' li:last-child' ).attr('data-id', (parseInt(last_id,10)+1) );
                            el.find( '#' + id + ' li:last-child' ).removeAttr( 'style' );
                            el.find( '#' + id + ' li:last-child select' ).val( '' );
                            el.find( '#' + id + ' li:last-child input[type="text"]' ).val( '' );
                            el.find( '#' + id + ' li:last-child input[type="number"]' ).val( '' );
                            el.find( '#' + id + ' li:last-child select' ).attr( 'name', name+'[opr]' );
                            el.find( '#' + id + ' li:last-child input[type="text"]' ).attr( 'name', name+'[width]' );
                            el.find( '#' + id + ' li:last-child input[type="number"]' ).attr( 'name', name+'[cols]' );
                        }
                    }
                );
            }
        );
    };
})( jQuery );