.redux-container-multi_bp_select {
    select {
        height: 27px;
	    vertical-align: top;
    }

    ul.redux-multi-bp-select {
        margin: 0;
        padding: 0;
    }

    .redux-multi-bp-select-add {
        clear: both;
        margin: 5px 0;
    }

    .redux-multi-bp-select li {
        padding-bottom: 8px;
        
        .width, .cols {
            max-width: 70px;
            text-align: center;
        }

        .cols {
            padding-left: 1.3em;
        }
    }
}

@media screen and (max-width: 1200px) {
    .redux-container-multi_bp_select {
        .redux-multi-bp-select li {
            padding-top: 5px;
            padding-bottom: 5px;
            border-bottom: 1px solid #E7E7E7;
        }
    }
}

@media screen and (max-width: 782px) {
    .redux-container-multi_bp_select .redux-multi-bp-select li {
        select, input {
            width: 100%;
            max-width: 100% !important;
            text-align: center !important;
        }

        span.expl {
            display: inline-block;
            width: 100%;
            text-align: center;
        }

        .redux-multi-bp-select-remove {
            margin: 0;
            //float: right;
        }
    }
}

.redux-container .redux-multi-bp-select-remove, 
.redux-container a.redux-multi-bp-select-remove,  {
    //color: #F00;
    padding: 2px 4px;
    margin-left: 5px;

    //background: orange;
    &:hover {
        //background: red;
        //color: #fff;
        text-decoration: none;
    }
}

.wp-customizer {
    .redux-container-multi_bp_select {
        .button {
            float: right;
        }
        .redux-multi-bp-select-remove {
            float: right;
            margin-bottom: 5px;
        }
        ul.redux-multi-bp-select input {
            width: 100% !important;
        }
    }
}
