.redux-container-multi_bp_select select{height:27px;vertical-align:top}.redux-container-multi_bp_select ul.redux-multi-bp-select{margin:0;padding:0}.redux-container-multi_bp_select .redux-multi-bp-select-add{clear:both;margin:5px 0}.redux-container-multi_bp_select .redux-multi-bp-select li{padding-bottom:8px}.redux-container-multi_bp_select .redux-multi-bp-select li .width,.redux-container-multi_bp_select .redux-multi-bp-select li .cols{max-width:70px;text-align:center}.redux-container-multi_bp_select .redux-multi-bp-select li .cols{padding-left:1.3em}@media screen and (max-width: 1200px){.redux-container-multi_bp_select .redux-multi-bp-select li{padding-top:5px;padding-bottom:5px;border-bottom:1px solid #E7E7E7}}@media screen and (max-width: 782px){.redux-container-multi_bp_select .redux-multi-bp-select li select,.redux-container-multi_bp_select .redux-multi-bp-select li input{width:100%;max-width:100% !important;text-align:center !important}.redux-container-multi_bp_select .redux-multi-bp-select li span.expl{display:inline-block;width:100%;text-align:center}.redux-container-multi_bp_select .redux-multi-bp-select li .redux-multi-bp-select-remove{margin:0}}.redux-container .redux-multi-bp-select-remove,.redux-container a.redux-multi-bp-select-remove{padding:2px 4px;margin-left:5px}.redux-container .redux-multi-bp-select-remove:hover,.redux-container a.redux-multi-bp-select-remove:hover{text-decoration:none}.wp-customizer .redux-container-multi_bp_select .button{float:right}.wp-customizer .redux-container-multi_bp_select .redux-multi-bp-select-remove{float:right;margin-bottom:5px}.wp-customizer .redux-container-multi_bp_select ul.redux-multi-bp-select input{width:100% !important}
/*# sourceMappingURL=field_multi_bp_select.css.map */
